# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.5.5

([Full Changelog](https://github.com/trungleduc/jupyterpack/compare/v0.5.4...7fc59dc7e5095defcc08b19d4cf18a39d7ed8d4c))

### Enhancements made

- Add Panel [#15](https://github.com/trungleduc/jupyterpack/pull/15) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

The following people contributed discussions, new ideas, code and documentation contributions, and review.
See [our definition of contributors](https://github-activity.readthedocs.io/en/latest/#how-does-this-tool-define-contributions-in-the-reports).

([GitHub contributors page for this release](https://github.com/trungleduc/jupyterpack/graphs/contributors?from=2025-12-28&to=2026-01-02&type=c))

@trungleduc ([activity](https://github.com/search?q=repo%3Atrungleduc%2Fjupyterpack+involves%3Atrungleduc+updated%3A2025-12-28..2026-01-02&type=Issues))

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.5.4

([Full Changelog](https://github.com/trungleduc/jupyterpack/compare/v0.5.3...e4e3e1ec6a792da4345a7f5f94fde1328a10bcc8))

### Enhancements made

- add launcher items [#14](https://github.com/trungleduc/jupyterpack/pull/14) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

The following people contributed discussions, new ideas, code and documentation contributions, and review.
See [our definition of contributors](https://github-activity.readthedocs.io/en/latest/#how-does-this-tool-define-contributions-in-the-reports).

([GitHub contributors page for this release](https://github.com/trungleduc/jupyterpack/graphs/contributors?from=2025-12-27&to=2025-12-28&type=c))

@trungleduc ([activity](https://github.com/search?q=repo%3Atrungleduc%2Fjupyterpack+involves%3Atrungleduc+updated%3A2025-12-27..2025-12-28&type=Issues))

## 0.5.3

([Full Changelog](https://github.com/trungleduc/jupyterpack/compare/v0.5.2...83f914708f8ba2dc853a6fd46f25d0fc489e523b))

### Bugs fixed

- remove pyodide_http [#13](https://github.com/trungleduc/jupyterpack/pull/13) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

The following people contributed discussions, new ideas, code and documentation contributions, and review.
See [our definition of contributors](https://github-activity.readthedocs.io/en/latest/#how-does-this-tool-define-contributions-in-the-reports).

([GitHub contributors page for this release](https://github.com/trungleduc/jupyterpack/graphs/contributors?from=2025-12-27&to=2025-12-27&type=c))

@trungleduc ([activity](https://github.com/search?q=repo%3Atrungleduc%2Fjupyterpack+involves%3Atrungleduc+updated%3A2025-12-27..2025-12-27&type=Issues))

## 0.5.2

([Full Changelog](https://github.com/trungleduc/jupyterpack/compare/v0.5.1...0114e175251e512eadd2e27393994dc6412fa19d))

### Enhancements made

- add default deps [#12](https://github.com/trungleduc/jupyterpack/pull/12) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

The following people contributed discussions, new ideas, code and documentation contributions, and review.
See [our definition of contributors](https://github-activity.readthedocs.io/en/latest/#how-does-this-tool-define-contributions-in-the-reports).

([GitHub contributors page for this release](https://github.com/trungleduc/jupyterpack/graphs/contributors?from=2025-11-27&to=2025-12-27&type=c))

@trungleduc ([activity](https://github.com/search?q=repo%3Atrungleduc%2Fjupyterpack+involves%3Atrungleduc+updated%3A2025-11-27..2025-12-27&type=Issues))

## 0.5.1

No merged PRs

## 0.5.0

([Full Changelog](https://github.com/trungleduc/jupyterpack/compare/v0.4.0...4c5e398823d753aa4373c951508c9313f0441ce3))

### Enhancements made

- asgi server [#11](https://github.com/trungleduc/jupyterpack/pull/11) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyterpack/graphs/contributors?from=2025-11-09&to=2025-11-27&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyterpack+involves%3Atrungleduc+updated%3A2025-11-09..2025-11-27&type=Issues)

## 0.4.0

([Full Changelog](https://github.com/trungleduc/jupyterpack/compare/v0.3.0...28c9dd5f2c2b438f003b8850eba2b95df140caf0))

### Enhancements made

- Refactor python [#10](https://github.com/trungleduc/jupyterpack/pull/10) ([@trungleduc](https://github.com/trungleduc))
- Auto reload [#9](https://github.com/trungleduc/jupyterpack/pull/9) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyterpack/graphs/contributors?from=2025-10-30&to=2025-11-09&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyterpack+involves%3Atrungleduc+updated%3A2025-10-30..2025-11-09&type=Issues)

## 0.3.0

([Full Changelog](https://github.com/trungleduc/jupyterpack/compare/v0.2.1...62cb3868d828e99753b72dc9e770aa99b38a6c1c))

### Enhancements made

- Refactor python code [#8](https://github.com/trungleduc/jupyterpack/pull/8) ([@trungleduc](https://github.com/trungleduc))
- streamlit [#7](https://github.com/trungleduc/jupyterpack/pull/7) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyterpack/graphs/contributors?from=2025-10-01&to=2025-10-30&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyterpack+involves%3Atrungleduc+updated%3A2025-10-01..2025-10-30&type=Issues)

## 0.2.1

([Full Changelog](https://github.com/trungleduc/jupyterpack/compare/v0.2.0...5fb3882b63c2497b1d485e04031e259cdabae36c))

### Enhancements made

- update fetch rule [#6](https://github.com/trungleduc/jupyterpack/pull/6) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyterpack/graphs/contributors?from=2025-10-01&to=2025-10-01&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyterpack+involves%3Atrungleduc+updated%3A2025-10-01..2025-10-01&type=Issues)

## 0.2.0

([Full Changelog](https://github.com/trungleduc/jupyterpack/compare/12083f5da5f8428ac882173ba1053ac83e9c2055...595d35d7591d91efbede78033911bfb633ee48b0))

### Enhancements made

- ping frame [#5](https://github.com/trungleduc/jupyterpack/pull/5) ([@trungleduc](https://github.com/trungleduc))
- Fix base url [#2](https://github.com/trungleduc/jupyterpack/pull/2) ([@trungleduc](https://github.com/trungleduc))
- Reboot [#1](https://github.com/trungleduc/jupyterpack/pull/1) ([@trungleduc](https://github.com/trungleduc))

### Other merged PRs

- keep sw alive [#4](https://github.com/trungleduc/jupyterpack/pull/4) ([@trungleduc](https://github.com/trungleduc))
- update readme [#3](https://github.com/trungleduc/jupyterpack/pull/3) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyterpack/graphs/contributors?from=2025-02-09&to=2025-10-01&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyterpack+involves%3Atrungleduc+updated%3A2025-02-09..2025-10-01&type=Issues)
